import { EditorView } from '@codemirror/view';
import { OptionsType, PublicConfigType, LocalFileType, DefaultConfigType, EventsType, LoadersType } from './type';
import './style/theme.less';
import './style/index.less';
export default class MiniSandbox {
    static version: string;
    static encode: (value: string) => string;
    static decode: (value: string) => string;
    readonly version: string;
    el: HTMLDivElement;
    files: {
        [filename: string]: LocalFileType;
    };
    fileList: Required<LocalFileType>[];
    loaders: LoadersType;
    publicConfig: Required<Omit<PublicConfigType, 'importMap'>>;
    defaultConfig: Required<DefaultConfigType>;
    events: Required<EventsType>;
    editor: EditorView;
    fileIndex: number;
    currFile: LocalFileType;
    currTemplate: LocalFileType;
    templateTypeSet: Set<string>;
    loading: boolean;
    isClick: boolean;
    iframe: HTMLIFrameElement;
    loadEl: HTMLDivElement;
    codeEl: HTMLDivElement;
    editorEl: HTMLDivElement;
    lineEl: HTMLDivElement;
    bodyEl: HTMLDivElement;
    ldqResource: string[];
    run: Function;
    constructor(options?: OptionsType);
    initOptions(options: OptionsType): void;
    init(): Promise<void>;
    reset(): void;
    private initDom;
    private initMenu;
    private initEvent;
    private handleChange;
    private initCodeMirror;
    private changeTab;
    private changeLang;
    setValue(value: string): void;
    getValue(): string;
    getJSONString(): string;
    setCode(code: string): void;
    getCode(value?: string): string;
    setStyle(el: HTMLDivElement, styles: {
        [key: string]: string | number;
    }): void;
    private addClass;
    getResource(src: string): Promise<string>;
    private triggleLoading;
    triggleTheme(theme?: "light" | "dark"): void;
    triggleDirection(direction?: DefaultConfigType['direction']): void;
    render(isReload?: boolean): Promise<void>;
}
